pub struct CommonOptions {
pub local_path: Option<String>,
pub remote_path: Option<String>,
pub upload_ratelimit: Option<u64>,
pub rsh: Option<String>,
}Expand description
The common options that can be used for every borg command
Fields
local_path: Option<String>The local path to the borg executable. (default = “borg”)
remote_path: Option<String>The remote path to the borg executable. (default = “borg”)
upload_ratelimit: Option<u64>set network upload rate limit in kiByte/s (0 = unlimited)
rsh: Option<String>Use this command to connect to the ‘borg serve’ process (default: “ssh”)
This can be useful to specify an alternative ssh key: “ssh -i /path/to/privkey”