Module errors

Module errors 

All errors of this crate are defined in this module

Enums

CompactError
The errors that can be returned from crate::sync::compact
CreateError
The errors of a borg create command
ExtractError
The errors that can be returned from crate::sync::extract
InitError
The possible errors that can get returned from crate::sync::init
ListError
The errors that can be returned from crate::sync::list
MountError
The errors that can be returned from crate::sync::mount
PruneError
The errors that can be returned from crate::sync::prune