Module sync

Module sync 

The synchronous versions of the borg command are defined in this module

Functions

compact
This command frees repository space by compacting segments.
create
This command creates a backup archive containing all files found while recursively traversing all paths specified. Paths are added to the archive as they are given, that means if relative paths are desired, the command has to be run from the correct directory.
extract
Extract the contents of an archive.
init
The entry point for the borg init command
list
The entry point for the borg list command
mount
Mount an archive or repo as a FUSE filesystem.
prune
The entry point for the borg init command
umount
Unmount a previously mounted archive or repository.