All errors of this crate are defined in this module
Enums
- Compact
Error - The errors that can be returned from crate::sync::compact
- Create
Error - The errors of a borg create command
- Extract
Error - The errors that can be returned from crate::sync::extract
- Init
Error - The possible errors that can get returned from crate::sync::init
- List
Error - The errors that can be returned from crate::sync::list
- Mount
Error - The errors that can be returned from crate::sync::mount
- Prune
Error - The errors that can be returned from crate::sync::prune